@@ -34,6 +34,7 @@
 #include "osal_preproc.h"
 #include "osal_dynamiclib.h"
 
+#include "main.h"
 #include "version.h"
 #include "core_interface.h"
 
@@ -141,7 +142,7 @@ m64p_error AttachCoreLib(const char *CoreLibFilepath)
     /* if we haven't found a good core library by now, then we're screwed */
     if (rval != M64ERR_SUCCESS || CoreHandle == NULL)
     {
-        fprintf(stderr, "AttachCoreLib() Error: failed to find Mupen64Plus Core library\n");
+        DebugMessage(M64MSG_ERROR, "AttachCoreLib() Error: failed to find Mupen64Plus Core library");
         CoreHandle = NULL;
         return M64ERR_INPUT_NOT_FOUND;
     }
@@ -151,7 +152,7 @@ m64p_error AttachCoreLib(const char *CoreLibFilepath)
     CoreVersionFunc = (ptr_PluginGetVersion) osal_dynlib_getproc(CoreHandle, "PluginGetVersion");
     if (CoreVersionFunc == NULL)
     {
-        fprintf(stderr, "AttachCoreLib() Error: Shared library '%s' invalid; no PluginGetVersion() function found.\n", CoreLibFilepath);
+        DebugMessage(M64MSG_ERROR, "AttachCoreLib() Error: Shared library '%s' invalid; no PluginGetVersion() function found.", CoreLibFilepath);
         osal_dynlib_close(CoreHandle);
         CoreHandle = NULL;
         return M64ERR_INPUT_INVALID;
@@ -162,12 +163,12 @@ m64p_error AttachCoreLib(const char *CoreLibFilepath)
     const char *CoreName = NULL;
     (*CoreVersionFunc)(&PluginType, &CoreVersion, &g_CoreAPIVersion, &CoreName, &g_CoreCapabilities);
     if (PluginType != M64PLUGIN_CORE)
-        fprintf(stderr, "AttachCoreLib() Error: Shared library '%s' invalid; this is not the emulator core.\n", CoreLibFilepath);
+        DebugMessage(M64MSG_ERROR, "AttachCoreLib() Error: Shared library '%s' invalid; this is not the emulator core.", CoreLibFilepath);
     else if (CoreVersion < MINIMUM_CORE_VERSION)
-        fprintf(stderr, "AttachCoreLib() Error: Shared library '%s' incompatible; core version %i.%i.%i is below minimum supported %i.%i.%i\n",
+        DebugMessage(M64MSG_ERROR, "AttachCoreLib() Error: Shared library '%s' incompatible; core version %i.%i.%i is below minimum supported %i.%i.%i",
                 CoreLibFilepath, VERSION_PRINTF_SPLIT(CoreVersion), VERSION_PRINTF_SPLIT(MINIMUM_CORE_VERSION));
     else if ((g_CoreAPIVersion & 0xffff0000) != (CORE_API_VERSION & 0xffff0000))
-        fprintf(stderr, "AttachCoreLib() Error: Shared library '%s' incompatible; core API major version %i.%i.%i doesn't match with this application (%i.%i.%i)\n",
+        DebugMessage(M64MSG_ERROR, "AttachCoreLib() Error: Shared library '%s' incompatible; core API major version %i.%i.%i doesn't match with this application (%i.%i.%i)",
                 CoreLibFilepath, VERSION_PRINTF_SPLIT(g_CoreAPIVersion), VERSION_PRINTF_SPLIT(CORE_API_VERSION));
     else
         Compatible = 1;
@@ -184,7 +185,7 @@ m64p_error AttachCoreLib(const char *CoreLibFilepath)
     CoreAPIVersionFunc = (ptr_CoreGetAPIVersions) osal_dynlib_getproc(CoreHandle, "CoreGetAPIVersions");
     if (CoreAPIVersionFunc == NULL)
     {
-        fprintf(stderr, "AttachCoreLib() Error: Library '%s' broken; no CoreAPIVersionFunc() function found.\n", CoreLibFilepath);
+        DebugMessage(M64MSG_ERROR, "AttachCoreLib() Error: Library '%s' broken; no CoreAPIVersionFunc() function found.", CoreLibFilepath);
         osal_dynlib_close(CoreHandle);
         CoreHandle = NULL;
         return M64ERR_INPUT_INVALID;
@@ -193,7 +194,7 @@ m64p_error AttachCoreLib(const char *CoreLibFilepath)
     (*CoreAPIVersionFunc)(&ConfigAPIVersion, &DebugAPIVersion, &VidextAPIVersion, NULL);
     if ((ConfigAPIVersion & 0xffff0000) != (CONFIG_API_VERSION & 0xffff0000))
     {
-        fprintf(stderr, "AttachCoreLib() Error: Emulator core '%s' incompatible; Config API major version %i.%i.%i doesn't match application: %i.%i.%i\n",
+        DebugMessage(M64MSG_ERROR, "AttachCoreLib() Error: Emulator core '%s' incompatible; Config API major version %i.%i.%i doesn't match application: %i.%i.%i",
                 CoreLibFilepath, VERSION_PRINTF_SPLIT(ConfigAPIVersion), VERSION_PRINTF_SPLIT(CONFIG_API_VERSION));
         osal_dynlib_close(CoreHandle);
         CoreHandle = NULL;
@@ -201,13 +202,13 @@ m64p_error AttachCoreLib(const char *CoreLibFilepath)
     }
 
     /* print some information about the core library */
-    printf("UI-console: attached to core library '%s' version %i.%i.%i\n", CoreName, VERSION_PRINTF_SPLIT(CoreVersion));
+    DebugMessage(M64MSG_INFO, "attached to core library '%s' version %i.%i.%i", CoreName, VERSION_PRINTF_SPLIT(CoreVersion));
     if (g_CoreCapabilities & M64CAPS_DYNAREC)
-        printf("            Includes support for Dynamic Recompiler.\n");
+        DebugMessage(M64MSG_INFO, "            Includes support for Dynamic Recompiler.");
     if (g_CoreCapabilities & M64CAPS_DEBUGGER)
-        printf("            Includes support for MIPS r4300 Debugger.\n");
+        DebugMessage(M64MSG_INFO, "            Includes support for MIPS r4300 Debugger.");
     if (g_CoreCapabilities & M64CAPS_CORE_COMPARE)
-        printf("            Includes support for r4300 Core Comparison.\n");
+        DebugMessage(M64MSG_INFO, "            Includes support for r4300 Core Comparison.");
 
     /* get function pointers to the common and front-end functions */
     CoreErrorMessage = (ptr_CoreErrorMessage) osal_dynlib_getproc(CoreHandle, "CoreErrorMessage");
